{ config, pkgs, ... }:

{
  imports = [
    ./common-gui.nix
  ];

  environment.systemPackages = with pkgs; [
    i3
    i3status
    rofi
    rofi-pass
    feh
    gnome3.gnome-keyring
    networkmanagerapplet
    gnome3.nautilus # in closure of gnome-terminal anyhow
    pcmanfm
    # colord
    evince
    arandr
    xss-lock i3lock i3lock-color
    xdotool
    scrot
    pavucontrol
    pasystray
    gnome3.dconf-editor
    unclutter-xfixes
    dunst

    xorg.xev

    # gnome3 core packages
    desktop-file-utils shared-mime-info
    glib gtk3
    glib-networking gvfs dconf
    gnome3.gnome-settings-daemon
    gnome-themes-extra gnome3.adwaita-icon-theme
    hicolor-icon-theme
  ];

  services.xserver = {
    enable = true;

    displayManager = {
      # slim.enable = true;
      # slim.defaultUser = "gebner";
      # # slim.autoLogin = true;

      lightdm.enable = true;
      # startx.enable = true;
      # sddm.enable = true;

      defaultSession = "i3wm";
    };

    desktopManager = {
      xterm.enable = false;

      session = [ {
        name = "i3wm";
        start = ''
          export XDG_DATA_DIRS=/run/current-system/sw/share/''${XDG_DATA_DIRS:+:}$XDG_DATA_DIRS
          export $(${pkgs.gnome3.gnome-keyring}/bin/gnome-keyring-daemon --start --components=pkcs11,secrets,ssh)
          export XDG_CURRENT_DESKTOP=X-Generic
          i3 &
          waitPID=$!
        '';
      } ];
    };

    updateDbusEnvironment = true;

    layout = "us";
    xkbVariant = "altgr-intl";
    xkbOptions = "caps:ctrl_modifier";
  };

  # services.dbus.socketActivated = true;
  services.dbus.packages = with pkgs; [ dunst ];
  systemd.packages = [ pkgs.dunst ];

}
