{ config, pkgs, ... }:

{
  imports = [
    ./common-gui.nix
  ];

  environment.systemPackages = with pkgs; [
    i3status
    (waybar.override { pulseSupport = true; })
    rofi-wayland
    ydotool
    wtype
    wl-clipboard
    feh
    gnome3.gnome-keyring
    networkmanagerapplet
    pcmanfm
    evince
    grim
    mako
    pavucontrol
    paprefs
    gnome3.dconf-editor

    xdg_utils # for xdg-open

    # gnome3 core packages
    desktop-file-utils shared-mime-info
    glib gtk3
    glib-networking gvfs dconf
    gnome-themes-extra gnome3.adwaita-icon-theme
    hicolor-icon-theme

    # for QT_QPA_PLATFORM=wayland
    qt5.qtwayland

    wdisplays

    playerctl

    xorg.xlsclients
  ];

  nixpkgs.config.packageOverrides = pkgs: with pkgs; {
    firefox = firefox-wayland;
  };

  # services.dbus.socketActivated = true;

  programs.sway = {
    enable = true;

    wrapperFeatures.gtk = true;

    extraSessionCommands = ''
      export SDL_VIDEODRIVER=wayland

      # https://github.com/swaywm/sway/issues/4506
      export QT_QPA_PLATFORM=xcb
      # export QT_QPA_PLATFORM=wayland
      export QT_WAYLAND_DISABLE_WINDOWDECORATION=1

      # Fix for some Java AWT applications (e.g. Android Studio),
      # use this if they aren't displayed properly:
      export _JAVA_AWT_WM_NONREPARENTING=1

      # rust winit's wayland support is broken for input methods
      export WINIT_UNIX_BACKEND=x11

      export XDG_DATA_DIRS=/run/current-system/sw/share/''${XDG_DATA_DIRS:+:}$XDG_DATA_DIRS
      export $(${pkgs.gnome3.gnome-keyring}/bin/gnome-keyring-daemon --start --components=pkcs11,secrets,ssh,gpg)
      export XDG_CURRENT_DESKTOP=sway
    '';
  };

  # services.xserver = {
  #   enable = true;
  #   libinput.enable = true;
  #   # displayManager.lightdm.enable = true;
  #   displayManager.defaultSession = "sway";
  # };

  services.dbus.packages = with pkgs; [ mako ];

  xdg.portal.extraPortals = [ pkgs.xdg-desktop-portal-wlr ];

}
